@@ -183,7 +183,7 @@ static model_filter_init_t model_filter_init[2] = {
     // The dynamic analog range of one voice is approximately 1.5V,
     1.5,
     // riding at a DC level of approximately 5.0V.
-    5.0,
+    5.075,
     // Capacitor value.
     470e-12,
     // Transistor parameters.
@@ -204,7 +204,7 @@ static model_filter_init_t model_filter_init[2] = {
     opamp_voltage_8580,
     sizeof(opamp_voltage_8580)/sizeof(*opamp_voltage_8580),
     // FIXME: Measure for the 8580.
-    0.2,
+    0.25,
     // The 4.75V voltage for the virtual ground is generated by a PolySi resistor divider
     4.80, // FIXME
     // Capacitor value.
@@ -225,7 +225,6 @@ static model_filter_init_t model_filter_init[2] = {
   }
 };
 
-unsigned short Filter::resonance[16][1 << 16];
 unsigned short Filter::vcr_kVg[1 << 16];
 unsigned short Filter::vcr_n_Ids_term[1 << 16];
 int Filter::n_snake;
@@ -255,6 +254,8 @@ Filter::Filter()
   if (!class_init) {
     double tmp_n_param[2];
 
+    unsigned int dac_bits = 11;
+
     // Temporary tables for op-amp transfer function.
     unsigned int* voltages = new unsigned int[1 << 16];
     opamp_t* opamp = new opamp_t[1 << 16];
@@ -312,23 +313,23 @@ Filter::Filter()
         //
         //   m*2^N*x = x_n - m*2^N*xmin
         //
-        scaled_voltage[fi.opamp_voltage_size - 1 - i][0] = int(N16*(fi.opamp_voltage[i][1] - fi.opamp_voltage[i][0] + denorm)/2 + 0.5);
+        scaled_voltage[fi.opamp_voltage_size - 1 - i][0] = N16*(fi.opamp_voltage[i][1] - fi.opamp_voltage[i][0] + denorm)/2.;
         scaled_voltage[fi.opamp_voltage_size - 1 - i][1] = N31*(fi.opamp_voltage[i][0] - vmin);
       }
 
-      // Clamp x to 16 bits (rounding may cause overflow).
-      if (scaled_voltage[fi.opamp_voltage_size - 1][0] >= (1 << 16)) {
+      // Clamp x to 16 bit range (rounding may cause overflow).
+      if (scaled_voltage[fi.opamp_voltage_size - 1][0] > 65535.) {
         // The last point is repeated.
         scaled_voltage[fi.opamp_voltage_size - 1][0] =
-            scaled_voltage[fi.opamp_voltage_size - 2][0] = (1 << 16) - 1;
+            scaled_voltage[fi.opamp_voltage_size - 2][0] = 65535.;
       }
 
       interpolate(scaled_voltage, scaled_voltage + fi.opamp_voltage_size - 1,
                     PointPlotter<unsigned int>(voltages), 1.0);
 
       // Store both fn and dfn in the same table.
-      mf.ak = (int)scaled_voltage[0][0];
-      mf.bk = (int)scaled_voltage[fi.opamp_voltage_size - 1][0];
+      mf.ak = (int)(scaled_voltage[0][0] + 0.5);
+      mf.bk = (int)(scaled_voltage[fi.opamp_voltage_size - 1][0] + 0.5);
       int j;
       for (j = 0; j < mf.ak; j++) {
         opamp[j].vx = 0;
@@ -355,20 +356,7 @@ Filter::Filter()
       // it's the same as the second point's
       opamp[mf.ak].dvx = opamp[mf.ak+1].dvx;
 
-      // Create lookup tables for gains / summers.
-
-      // 4 bit "resistor" ladders in the bandpass resonance gain and the audio
-      // output gain necessitate 16 gain tables.
-      // From die photographs of the bandpass and volume "resistor" ladders
-      // it follows that gain ~ vol/8 and 1/Q ~ ~res/8 (assuming ideal
-      // op-amps and ideal "resistors").
-      for (int n8 = 0; n8 < 16; n8++) {
-        int n = n8 << 4;  // Scaled by 2^7
-        int x = mf.ak;
-        for (int vi = 0; vi < (1 << 16); vi++) {
-          mf.gain[n8][vi] = solve_gain(opamp, n, vi, x, mf);
-        }
-      }
+      // Create lookup tables.
 
       // The filter summer operates at n ~ 1, and has 5 fundamentally different
       // input configurations (2 - 6 input "resistors").
@@ -391,16 +379,18 @@ Filter::Filter()
         offset += size;
       }
 
-      // The audio mixer operates at n ~ 8/6, and has 8 fundamentally different
+      // The audio mixer operates at n ~ 8/6 (6581) 8/5 (8580),
+      // and has 8 fundamentally different
       // input configurations (0 - 7 input "resistors").
       //
       // All "on", transistors are modeled as one - see comments above for
       // the filter summer.
+      int divider = m==0 ? 6 : 5;
       offset = 0;
       size = 1;  // Only one lookup element for 0 input "resistors".
       for (int l = 0; l < 8; l++) {
         int idiv = l;                 // 0 - 7 input "resistors".
-        int n_idiv = (idiv << 7)*8/6; // n*idiv, scaled by 2^7
+        int n_idiv = (idiv << 7)*8/divider; // n*idiv, scaled by 2^7
         if (idiv == 0) {
           // Avoid division by zero; the result will be correct since
           // n_idiv = 0.
@@ -415,122 +405,213 @@ Filter::Filter()
         size = (l + 1) << 16;
       }
 
+      // 4 bit "resistor" ladders in the audio
+      // output gain necessitate 16 gain tables.
+      // From die photographs of the volume "resistor" ladders
+      // it follows that gain ~ vol/12 (6581) vol/16 (8580)
+      // (assuming ideal op-amps and ideal "resistors").
+      divider = m==0 ? 12 : 16;
+      for (int n8 = 0; n8 < 16; n8++) {
+        int n = (n8 << 7) / divider;  // Scaled by 2^7
+        int x = mf.ak;
+        for (int vi = 0; vi < (1 << 16); vi++) {
+          mf.gain[n8][vi] = solve_gain(opamp, n, vi, x, mf);
+        }
+      }
+
       // Create lookup table mapping capacitor voltage to op-amp input voltage:
       // vc -> vx
-      for (int m = 0; m < (1 << 16); m++) {
-        mf.opamp_rev[m] = opamp[m].vx;
+      for (int i = 0; i < (1 << 16); i++) {
+        mf.opamp_rev[i] = opamp[i].vx;
       }
 
       mf.vc_max = (int)(N30*(fi.opamp_voltage[0][1] - fi.opamp_voltage[0][0]));
       mf.vc_min = (int)(N30*(fi.opamp_voltage[fi.opamp_voltage_size - 1][1] - fi.opamp_voltage[fi.opamp_voltage_size - 1][0]));
-    }
 
-    // Free temporary table.
-    delete[] voltages;
+      if (m == 0) {
+        // 6581 only
 
-    unsigned int dac_bits = 11;
-
-    {
-      // 8580 only
-      for (int n8 = 0; n8 < 16; n8++) {
-        int x = model_filter[1].ak;
-        for (int vi = 0; vi < (1 << 16); vi++) {
-          resonance[n8][vi] = solve_gain(opamp, resGain[n8], vi, x, model_filter[1]);
-        }
-      }
-
-      // scaled 5 bits
-      n_param = (int)(tmp_n_param[1] * 32 + 0.5);
-
-      model_filter_init_t& fi = model_filter_init[1];
-      model_filter_t& f = model_filter[1];
-
-      double Vgt = (4.75 * 1.6) - fi.Vth;
-      nVgt = (int)(f.vo_N16 * (Vgt - fi.opamp_voltage[0][0]) + 0.5);
-
-      // DAC table.
-      // W/L ratio for frequency DAC, bits are proportional.
-      // scaled 5 bits
-      unsigned short dacWL = 3; // 0,0029296875 * 1024 (actual value is ~= 0.003075)
-      f.f0_dac[0] = dacWL;
-      for (int n = 1; n < (1 << dac_bits); n++) {
-        // Calculate W/L ratio for parallel NMOS resistances
-        unsigned short wl = 0;
-        for (unsigned int i = 0; i < dac_bits; i++) {
-          unsigned int bitmask = 1 << i;
-          if (n & bitmask) {
-            wl += dacWL * (bitmask<<1);
+        // In the MOS 6581, 1/Q is controlled linearly by res. From die photographs
+        // of the resonance "resistor" ladder it follows that 1/Q ~ ~res/8
+        // (assuming an ideal op-amp and ideal "resistors"). This implies that Q
+        // ranges from 0.533 (res = 0) to 8 (res = E). For res = F, Q is actually
+        // theoretically unlimited, which is quite unheard of in a filter
+        // circuit.
+        //
+        // To obtain Q ~ 1/sqrt(2) = 0.707 for maximally flat frequency response,
+        // res should be set to 4: Q = 8/~4 = 8/11 = 0.7272 (again assuming an ideal
+        // op-amp and ideal "resistors").
+        //
+        // Q as low as 0.707 is not achievable because of low gain op-amps; res = 0
+        // should yield the flattest possible frequency response at Q ~ 0.8 - 1.0
+        // in the op-amp's pseudo-linear range (high amplitude signals will be
+        // clipped). As resonance is increased, the filter must be clocked more
+        // often to keep it stable.
+        for (int n8 = 0; n8 < 16; n8++) {
+          int n = (~n8 & 0xf) << (7 - 3);  // Scaled by 2^7
+          int x = mf.ak;
+          for (int vi = 0; vi < (1 << 16); vi++) {
+            mf.resonance[n8][vi] = solve_gain(opamp, n, vi, x, mf);
           }
         }
-        f.f0_dac[n] = wl;
+
+        Vw_bias = 0;
+
+        // Normalized snake current factor, 1 cycle at 1MHz.
+        // Fit in 5 bits.
+        n_snake = (int)(fi.WL_snake * tmp_n_param[0] + 0.5);
+
+        // DAC table.
+        build_dac_table(mf.f0_dac, dac_bits, fi.dac_2R_div_R, fi.dac_term);
+        for (int n = 0; n < (1 << dac_bits); n++) {
+          mf.f0_dac[n] = (unsigned short)(N16*(fi.dac_zero + mf.f0_dac[n]*fi.dac_scale/(1 << dac_bits) - vmin) + 0.5);
+        }
+      
+        // VCR table.
+        double k = fi.k;
+        double kVddt = N16*(k*(fi.Vdd - fi.Vth));
+        vmin *= N16;
+
+        for (int i = 0; i < (1 << 16); i++) {
+          // The table index is right-shifted 16 times in order to fit in
+          // 16 bits; the argument to sqrt is thus multiplied by (1 << 16).
+          //
+          // The returned value must be corrected for translation. Vg always
+          // takes part in a subtraction as follows:
+          //
+          //   k*Vg - Vx = (k*Vg - t) - (Vx - t)
+          //
+          // I.e. k*Vg - t must be returned.
+          double Vg = kVddt - sqrt((double)i*(1 << 16));
+          vcr_kVg[i] = (unsigned short)(k*Vg - vmin + 0.5);
+        }
+
+        /*
+          EKV model:
+      
+          Ids = Is*(if - ir)
+          Is = ((2*u*Cox*Ut^2)/k)*W/L
+          if = ln^2(1 + e^((k*(Vg - Vt) - Vs)/(2*Ut))
+          ir = ln^2(1 + e^((k*(Vg - Vt) - Vd)/(2*Ut))
+        */
+        double kVt = fi.k*fi.Vth;
+        double Ut = fi.Ut;
+        double Is = ((2*fi.uCox*Ut*Ut)/fi.k)*fi.WL_vcr;
+        // Normalized current factor for 1 cycle at 1MHz.
+        double N15 = N16/2;
+        double n_Is = N15*1.0e-6/fi.C*Is;
+
+        // kVg_Vx = k*Vg - Vx
+        // I.e. if k != 1.0, Vg must be scaled accordingly.
+        for (int kVg_Vx = 0; kVg_Vx < (1 << 16); kVg_Vx++) {
+          double log_term = log1p(exp((kVg_Vx/N16 - kVt)/(2*Ut)));
+          // Scaled by m*2^15
+          vcr_n_Ids_term[kVg_Vx] = (unsigned short)(n_Is*log_term*log_term);
+        }
+      } else {
+        // 8580 only
+
+        // In the MOS 8580, the resonance "resistor" ladder above the bp feedback
+        // op-amp is split in two parts; one ladder for the op-amp input and one
+        // ladder for the op-amp feedback.
+        //
+        // input:         feedback:
+        //
+        //             Rf
+        // Ri R4 RC R8    R3
+        //             R2
+        //             R1
+        //
+        //
+        // The "resistors" are switched in as follows by bits in register $17:
+        //
+        // feedback:
+        // R1: bit4&!bit5
+        // R2: !bit4&bit5
+        // R3: bit4&bit5
+        // Rf: always on
+        //
+        // input:
+        // R4: bit6&!bit7
+        // R8: !bit6&bit7
+        // RC: bit6&bit7
+        // Ri: !(R4|R8|RC) = !(bit6|bit7) = !bit6&!bit7
+        //
+        //
+        // The relative "resistor" values are approximately (using channel length):
+        //
+        // R1 = 15.3*Ri
+        // R2 =  7.3*Ri
+        // R3 =  4.7*Ri
+        // Rf =  1.4*Ri
+        // R4 =  1.4*Ri
+        // R8 =  2.0*Ri
+        // RC =  2.8*Ri
+        //
+        //
+        // Approximate values for 1/Q can now be found as follows (assuming an
+        // ideal op-amp):
+        //
+        // res  feedback  input  -gain (1/Q)
+        // ---  --------  -----  ----------
+        // 0   Rf        Ri     Rf/Ri      = 1/(Ri*(1/Rf))      = 1/0.71
+        // 1   Rf|R1     Ri     (Rf|R1)/Ri = 1/(Ri*(1/Rf+1/R1)) = 1/0.78
+        // 2   Rf|R2     Ri     (Rf|R2)/Ri = 1/(Ri*(1/Rf+1/R2)) = 1/0.85
+        // 3   Rf|R3     Ri     (Rf|R3)/Ri = 1/(Ri*(1/Rf+1/R3)) = 1/0.92
+        // 4   Rf        R4     Rf/R4      = 1/(R4*(1/Rf))      = 1/1.00
+        // 5   Rf|R1     R4     (Rf|R1)/R4 = 1/(R4*(1/Rf+1/R1)) = 1/1.10
+        // 6   Rf|R2     R4     (Rf|R2)/R4 = 1/(R4*(1/Rf+1/R2)) = 1/1.20
+        // 7   Rf|R3     R4     (Rf|R3)/R4 = 1/(R4*(1/Rf+1/R3)) = 1/1.30
+        // 8   Rf        R8     Rf/R8      = 1/(R8*(1/Rf))      = 1/1.43
+        // 9   Rf|R1     R8     (Rf|R1)/R8 = 1/(R8*(1/Rf+1/R1)) = 1/1.56
+        // A   Rf|R2     R8     (Rf|R2)/R8 = 1/(R8*(1/Rf+1/R2)) = 1/1.70
+        // B   Rf|R3     R8     (Rf|R3)/R8 = 1/(R8*(1/Rf+1/R3)) = 1/1.86
+        // C   Rf        RC     Rf/RC      = 1/(RC*(1/Rf))      = 1/2.00
+        // D   Rf|R1     RC     (Rf|R1)/RC = 1/(RC*(1/Rf+1/R1)) = 1/2.18
+        // E   Rf|R2     RC     (Rf|R2)/RC = 1/(RC*(1/Rf+1/R2)) = 1/2.38
+        // F   Rf|R3     RC     (Rf|R3)/RC = 1/(RC*(1/Rf+1/R3)) = 1/2.60
+        //
+        //
+        // These data indicate that the following function for 1/Q has been
+        // modeled in the MOS 8580:
+        //
+        // 1/Q = 2^(1/2)*2^(-x/8) = 2^(1/2 - x/8) = 2^((4 - x)/8)
+        for (int n8 = 0; n8 < 16; n8++) {
+          int x = mf.ak;
+          for (int vi = 0; vi < (1 << 16); vi++) {
+            mf.resonance[n8][vi] = solve_gain(opamp, resGain[n8], vi, x, mf);
+          }
+        }
+
+        // scaled 5 bits
+        n_param = (int)(tmp_n_param[1] * 32 + 0.5);
+
+        double Vgt = (fi.voice_DC_voltage * 1.6) - fi.Vth;
+        nVgt = (int)(N16 * (Vgt - vmin) + 0.5);
+
+        // DAC table.
+        // W/L ratio for frequency DAC, bits are proportional.
+        // scaled 5 bits
+        unsigned int dacWL = 806; // 0,00307464599609375 * 1024 * 256 (actual value is ~= 0.003075)
+        mf.f0_dac[0] = dacWL >> 8;
+        for (int n = 1; n < (1 << dac_bits); n++) {
+          // Calculate W/L ratio for parallel NMOS resistances
+          unsigned int wl = 0;
+          for (unsigned int i = 0; i < dac_bits; i++) {
+            unsigned int bitmask = 1 << i;
+            if (n & bitmask) {
+                wl += dacWL * (bitmask<<1);
+            }
+          }
+          mf.f0_dac[n] = wl >> 8;
+        }
       }
     }
 
-    // Free temporary table.
+    // Free temporary tables.
+    delete[] voltages;
     delete[] opamp;
 
-    {
-      // 6581 only
-      model_filter_init_t& fi = model_filter_init[0];
-      model_filter_t& f = model_filter[0];
-      double N16 = f.vo_N16;
-      double vmin = fi.opamp_voltage[0][0];
-
-      Vw_bias = 0;
-
-      // Normalized snake current factor, 1 cycle at 1MHz.
-      // Fit in 5 bits.
-      n_snake = (int)(fi.WL_snake * tmp_n_param[0] + 0.5);
-
-      // DAC table.
-      build_dac_table(f.f0_dac, dac_bits, fi.dac_2R_div_R, fi.dac_term);
-      for (int n = 0; n < (1 << dac_bits); n++) {
-        f.f0_dac[n] = (unsigned short)(N16*(fi.dac_zero + f.f0_dac[n]*fi.dac_scale/(1 << dac_bits) - vmin) + 0.5);
-      }
-
-      // VCR table.
-      double k = fi.k;
-      double kVddt = N16*(k*(fi.Vdd - fi.Vth));
-      vmin *= N16;
-
-      for (int i = 0; i < (1 << 16); i++) {
-        // The table index is right-shifted 16 times in order to fit in
-        // 16 bits; the argument to sqrt is thus multiplied by (1 << 16).
-        //
-        // The returned value must be corrected for translation. Vg always
-        // takes part in a subtraction as follows:
-        //
-        //   k*Vg - Vx = (k*Vg - t) - (Vx - t)
-        //
-        // I.e. k*Vg - t must be returned.
-        double Vg = kVddt - sqrt((double)i*(1 << 16));
-        vcr_kVg[i] = (unsigned short)(k*Vg - vmin + 0.5);
-      }
-
-      /*
-        EKV model:
-
-        Ids = Is*(if - ir)
-        Is = ((2*u*Cox*Ut^2)/k)*W/L
-        if = ln^2(1 + e^((k*(Vg - Vt) - Vs)/(2*Ut))
-        ir = ln^2(1 + e^((k*(Vg - Vt) - Vd)/(2*Ut))
-      */
-      double kVt = fi.k*fi.Vth;
-      double Ut = fi.Ut;
-      double Is = ((2*fi.uCox*Ut*Ut)/fi.k)*fi.WL_vcr;
-      // Normalized current factor for 1 cycle at 1MHz.
-      double N15 = N16/2;
-      double n_Is = N15*1.0e-6/fi.C*Is;
-
-      // kVg_Vx = k*Vg - Vx
-      // I.e. if k != 1.0, Vg must be scaled accordingly.
-      for (int kVg_Vx = 0; kVg_Vx < (1 << 16); kVg_Vx++) {
-        double log_term = log1p(exp((kVg_Vx/N16 - kVt)/(2*Ut)));
-        // Scaled by m*2^15
-        vcr_n_Ids_term[kVg_Vx] = (unsigned short)(n_Is*log_term*log_term);
-      }
-    }
-
     class_init = true;
   }
 
@@ -565,7 +646,7 @@ void Filter::adjust_filter_bias(double dac_bias)
   // Gate voltage is controlled by the switched capacitor voltage divider
   // Ua = Ue * v = 4.75v  1<v<2
   model_filter_init_t& fi = model_filter_init[1];
-  double Vg = 4.75 * (dac_bias*6./100. + 1.6);
+  double Vg = fi.voice_DC_voltage * (dac_bias*6./100. + 1.6);
   double Vgt = Vg - fi.Vth;
   double vmin = fi.opamp_voltage[0][0];
 
@@ -618,7 +699,6 @@ void Filter::reset()
   Vlp = Vlp_x = Vlp_vc = 0;
 
   set_w0();
-  set_Q();
   set_sum_mix();
 }
 
@@ -641,7 +721,6 @@ void Filter::writeFC_HI(reg8 fc_hi)
 void Filter::writeRES_FILT(reg8 res_filt)
 {
   res = (res_filt >> 4) & 0x0f;
-  set_Q();
 
   filt = res_filt & 0x0f;
   set_sum_mix();
@@ -672,101 +751,6 @@ void Filter::set_w0()
   }
 }
 
-/*
-Set filter resonance.
-
-In the MOS 6581, 1/Q is controlled linearly by res. From die photographs
-of the resonance "resistor" ladder it follows that 1/Q ~ ~res/8
-(assuming an ideal op-amp and ideal "resistors"). This implies that Q
-ranges from 0.533 (res = 0) to 8 (res = E). For res = F, Q is actually
-theoretically unlimited, which is quite unheard of in a filter
-circuit.
-
-To obtain Q ~ 1/sqrt(2) = 0.707 for maximally flat frequency response,
-res should be set to 4: Q = 8/~4 = 8/11 = 0.7272 (again assuming an ideal
-op-amp and ideal "resistors").
-
-Q as low as 0.707 is not achievable because of low gain op-amps; res = 0
-should yield the flattest possible frequency response at Q ~ 0.8 - 1.0
-in the op-amp's pseudo-linear range (high amplitude signals will be
-clipped). As resonance is increased, the filter must be clocked more
-often to keep it stable.
-
-In the MOS 8580, the resonance "resistor" ladder above the bp feedback
-op-amp is split in two parts; one ladder for the op-amp input and one
-ladder for the op-amp feedback.
-
-input:         feedback:
-
-               Rf
-Ri R4 RC R8    R3
-               R2
-               R1
-
-
-The "resistors" are switched in as follows by bits in register $17:
-
-feedback:
-R1: bit4&!bit5
-R2: !bit4&bit5
-R3: bit4&bit5
-Rf: always on
-
-input:
-R4: bit6&!bit7
-R8: !bit6&bit7
-RC: bit6&bit7
-Ri: !(R4|R8|RC) = !(bit6|bit7) = !bit6&!bit7
-
-
-The relative "resistor" values are approximately (using channel length):
-
-R1 = 15.3*Ri
-R2 =  7.3*Ri
-R3 =  4.7*Ri
-Rf =  1.4*Ri
-R4 =  1.4*Ri
-R8 =  2.0*Ri
-RC =  2.8*Ri
-
-
-Approximate values for 1/Q can now be found as follows (assuming an
-ideal op-amp):
-
-res  feedback  input  -gain (1/Q)
----  --------  -----  ----------
- 0   Rf        Ri     Rf/Ri      = 1/(Ri*(1/Rf))      = 1/0.71
- 1   Rf|R1     Ri     (Rf|R1)/Ri = 1/(Ri*(1/Rf+1/R1)) = 1/0.78
- 2   Rf|R2     Ri     (Rf|R2)/Ri = 1/(Ri*(1/Rf+1/R2)) = 1/0.85
- 3   Rf|R3     Ri     (Rf|R3)/Ri = 1/(Ri*(1/Rf+1/R3)) = 1/0.92
- 4   Rf        R4     Rf/R4      = 1/(R4*(1/Rf))      = 1/1.00
- 5   Rf|R1     R4     (Rf|R1)/R4 = 1/(R4*(1/Rf+1/R1)) = 1/1.10
- 6   Rf|R2     R4     (Rf|R2)/R4 = 1/(R4*(1/Rf+1/R2)) = 1/1.20
- 7   Rf|R3     R4     (Rf|R3)/R4 = 1/(R4*(1/Rf+1/R3)) = 1/1.30
- 8   Rf        R8     Rf/R8      = 1/(R8*(1/Rf))      = 1/1.43
- 9   Rf|R1     R8     (Rf|R1)/R8 = 1/(R8*(1/Rf+1/R1)) = 1/1.56
- A   Rf|R2     R8     (Rf|R2)/R8 = 1/(R8*(1/Rf+1/R2)) = 1/1.70
- B   Rf|R3     R8     (Rf|R3)/R8 = 1/(R8*(1/Rf+1/R3)) = 1/1.86
- C   Rf        RC     Rf/RC      = 1/(RC*(1/Rf))      = 1/2.00
- D   Rf|R1     RC     (Rf|R1)/RC = 1/(RC*(1/Rf+1/R1)) = 1/2.18
- E   Rf|R2     RC     (Rf|R2)/RC = 1/(RC*(1/Rf+1/R2)) = 1/2.38
- F   Rf|R3     RC     (Rf|R3)/RC = 1/(RC*(1/Rf+1/R3)) = 1/2.60
-
-
-These data indicate that the following function for 1/Q has been
-modeled in the MOS 8580:
-
-  1/Q = 2^(1/2)*2^(-x/8) = 2^(1/2 - x/8) = 2^((4 - x)/8)
-
-*/
-void Filter::set_Q()
-{
-  // Cutoff for MOS 6581.
-  // The coefficient 8 is dispensed of later by right-shifting 3 times
-  // (2 ^ 3 = 8).
-  _8_div_Q = ~res & 0x0f;
-}
-
 // Set input routing bits.
 void Filter::set_sum_mix()
 {
