@@ -153,11 +153,11 @@ void ReSIDfp::model(SidConfig::sid_model_t model, bool digiboost)
     {
         case SidConfig::MOS6581:
             chipModel = reSIDfp::MOS6581;
+            m_sid.input(0);
             break;
         case SidConfig::MOS8580:
             chipModel = reSIDfp::MOS8580;
-            if (digiboost)
-                m_sid.input(-32768);
+            m_sid.input(digiboost ? -32768 : 0);
             break;
         default:
             m_status = false;
