@@ -139,6 +139,9 @@ void MOS6510::setRDY(bool newRDY)
  */
 void MOS6510::PushSR()
 {
+    // Set the B flag, 0 for hardware interrupts
+    // and 1 for BRK and PHP. Bit 5 is always 1
+    // https://wiki.nesdev.org/w/index.php?title=Status_flags#The_B_flag
     Push(flags.get() | (d1x1 ? 0x20 : 0x30));
 }
 
@@ -367,7 +370,7 @@ void MOS6510::FetchLowAddr()
 void MOS6510::FetchLowAddrX()
 {
     FetchLowAddr();
-    Cycle_EffectiveAddress = (Cycle_EffectiveAddress + Register_X) & 0xFF;
+    Cycle_EffectiveAddress = (Cycle_EffectiveAddress + Register_X) & 0xff;
 }
 
 /**
@@ -379,7 +382,7 @@ void MOS6510::FetchLowAddrX()
 void MOS6510::FetchLowAddrY()
 {
     FetchLowAddr();
-    Cycle_EffectiveAddress = (Cycle_EffectiveAddress + Register_Y) & 0xFF;
+    Cycle_EffectiveAddress = (Cycle_EffectiveAddress + Register_Y) & 0xff;
 }
 
 /**
@@ -472,7 +475,7 @@ void MOS6510::FetchLowPointer()
  */
 void MOS6510::FetchLowPointerX()
 {
-    endian_16lo8(Cycle_Pointer, (Cycle_Pointer + Register_X) & 0xFF);
+    endian_16lo8(Cycle_Pointer, (Cycle_Pointer + Register_X) & 0xff);
 }
 
 /**
@@ -758,7 +761,7 @@ void MOS6510::sh_instr()
 
     /*
      * When the addressing/indexing causes a page boundary crossing
-     * the highbyte of the target address is anded with the value stored.
+     * the highbyte of the target address is ANDed with the value stored.
      */
     if (adl_carry)
     {
@@ -2138,7 +2141,7 @@ void MOS6510::buildInstructionTable()
 void MOS6510::Initialise()
 {
     // Reset stack
-    Register_StackPointer = 0xFF;
+    Register_StackPointer = 0xff;
 
     // Reset Cycle Count
     cycleCount = (BRKn << 3) + 6; // fetchNextOpcode
@@ -2175,13 +2178,13 @@ void MOS6510::reset()
     Initialise();
 
     // Set processor port to the default values
-    cpuWrite(0, 0x2F);
+    cpuWrite(0, 0x2f);
     cpuWrite(1, 0x37);
 
     // Requires External Bits
     // Read from reset vector for program entry point
-    endian_16lo8(Cycle_EffectiveAddress, cpuRead(0xFFFC));
-    endian_16hi8(Cycle_EffectiveAddress, cpuRead(0xFFFD));
+    endian_16lo8(Cycle_EffectiveAddress, cpuRead(0xfffc));
+    endian_16hi8(Cycle_EffectiveAddress, cpuRead(0xfffd));
     Register_ProgramCounter = Cycle_EffectiveAddress;
 }
 
