@@ -50,6 +50,10 @@
 
 #define SAMPLERATE 48000
 
+#if __cplusplus < 201103L
+#  define unique_ptr auto_ptr
+#endif
+
 /*
  * Load ROM dump from file.
  * Allocate the buffer if file exists, otherwise return 0.
@@ -72,7 +76,7 @@ char* loadRom(const char* path, size_t romSize)
  * to play a SID tune from a file.
  * It uses OSS for audio output.
  */
-int main(int argc, char* argv[])
+int main(int, char* argv[])
 {
     sidplayfp m_engine;
 
@@ -89,7 +93,7 @@ int main(int argc, char* argv[])
     }
 
     // Set up a SID builder
-    std::auto_ptr<ReSIDfpBuilder> rs(new ReSIDfpBuilder("Demo"));
+    std::unique_ptr<ReSIDfpBuilder> rs(new ReSIDfpBuilder("Demo"));
 
     // Get the number of SIDs supported by the engine
     unsigned int maxsids = (m_engine.info ()).maxsids();
@@ -105,7 +109,7 @@ int main(int argc, char* argv[])
     }
 
     // Load tune from file
-    std::auto_ptr<SidTune> tune(new SidTune(argv[1]));
+    std::unique_ptr<SidTune> tune(new SidTune(argv[1]));
 
     // CHeck if the tune is valid
     if (!tune->getStatus())
@@ -148,7 +152,7 @@ int main(int argc, char* argv[])
     int bufferSize;
     ioctl(handle, SNDCTL_DSP_GETBLKSIZE, &bufferSize);
 
-    int bufferSamples = bufferSize / sizeof(short);
+    uint_least32_t bufferSamples = static_cast<uint_least32_t>(bufferSize) / sizeof(short);
 
     // Play
     std::vector<short> buffer(bufferSamples);
