@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- *  Copyright (C) 2014-2017 Leandro Nini
+ *  Copyright (C) 2014-2022 Leandro Nini
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,14 @@ using namespace UnitTest;
 SUITE(WaveformGenerator)
 {
 
+TEST(TestShiftRegisterInitValue)
+{
+    reSIDfp::WaveformGenerator generator;
+    generator.reset();
+
+    CHECK_EQUAL(0x3fffff, generator.shift_register);
+}
+
 TEST(TestClockShiftRegister)
 {
     reSIDfp::WaveformGenerator generator;
